expectedSiweDomain property
Domain the sign-in challenge must declare, or null to skip the check. See SiweChallenge.validate for why this defaults to off.
Implementation
final String? expectedSiweDomain;
Domain the sign-in challenge must declare, or null to skip the check. See SiweChallenge.validate for why this defaults to off.
final String? expectedSiweDomain;