SimpleOnchainApi class
Methods
-
approve({required PolygonWallet signerWallet, required String contractAddress, required String spender, required String amountHuman, bool waitForTx = true})
→ Future<Map<String, dynamic>>
-
-
balanceOfPublic(String address)
→ Future<Map<String, dynamic>>
-
-
buyToken({required PolygonWallet signerWallet, required String contractAddress, required String from, required String to, required String amountHuman, bool waitForTx = true})
→ Future<Map<String, dynamic>>
-
-
checkAccount({required PolygonWallet signerWallet, required String contractAddress, required String account})
→ Future<Map<String, dynamic>>
-
-
mint({required PolygonWallet signerWallet, required String contractAddress, required String receiver, required String amountHuman, bool waitForTx = true})
→ Future<Map<String, dynamic>>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
sellToken({required PolygonWallet signerWallet, required String contractAddress, required String from, required String to, required String amountHuman, bool waitForTx = true})
→ Future<Map<String, dynamic>>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
transfer({required PolygonWallet signerWallet, required String contractAddress, required String to, required String amountHuman, bool waitForTx = true})
→ Future<Map<String, dynamic>>
-
-
transferFrom({required PolygonWallet signerWallet, required String contractAddress, required String from, required String to, required String amountHuman, bool waitForTx = true})
→ Future<Map<String, dynamic>>
-